Class: RubyPicasa::RecentPhotos

Inherits:
User
  • Object
show all
Defined in:
lib/ruby_picasa/types.rb

Overview

Includes attributes and associations defined on Base and User, plus:

has_many :entries, :Photo, 'entry'

Instance Method Summary collapse

Methods inherited from User

#albums

Methods inherited from Base

#feed, #link, #next, #previous, #session, #session=, #tb, #thumbnail, #url

Instance Method Details

#photosObject

The current page of recently updated photos associated to the user.



188
189
190
# File 'lib/ruby_picasa/types.rb', line 188

def photos
  entries
end